==> apache-dubbo-3.1.11-src.zip: dubbo-dubbo-3.1.11/dubbo-common/src/main/java/org/apache/dubbo/common/config/PrefixedConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.dubbo.common.config;

import org.apache.dubbo.common.utils.StringUtils;

public class PrefixedConfiguration implements Configuration {

    private String prefix;

    private Configuration origin;

    public PrefixedConfiguration(Configuration origin, String prefix) {
        this.origin = origin;
        this.prefix = prefix;
    }

    @Override
    public Object getInternalProperty(String key) {
        if (StringUtils.isBlank(prefix)) {
            return origin.getInternalProperty(key);
        }

        Object value = origin.getInternalProperty(prefix + "." + key);
        if (!ConfigurationUtils.isEmptyValue(value)) {
            return value;
        }
        return null;
    }

}

==> apache-dubbo-3.2.2-src.zip: dubbo-dubbo-3.2.2/dubbo-common/src/main/java/org/apache/dubbo/common/config/PrefixedConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.dubbo.common.config;

import org.apache.dubbo.common.utils.StringUtils;

public class PrefixedConfiguration implements Configuration {

    private final String prefix;

    private final Configuration origin;

    public PrefixedConfiguration(Configuration origin, String prefix) {
        this.origin = origin;
        this.prefix = prefix;
    }

    @Override
    public Object getInternalProperty(String key) {
        if (StringUtils.isBlank(prefix)) {
            return origin.getInternalProperty(key);
        }

        Object value = origin.getInternalProperty(prefix + "." + key);
        if (!ConfigurationUtils.isEmptyValue(value)) {
            return value;
        }
        return null;
    }

}
